.. _swh-scanner:

Software Heritage - Code Scanner
================================

Source code scanner using the
`Software Heritage <https://www.softwareheritage.org/>`_
`archive <https://archive.softwareheritage.org/>`_
as knowledge base.


.. toctree::
   :maxdepth: 1
   :caption: Contents:

   cli

.. only:: standalone_package_doc

   Indices and tables
   ------------------

   * :ref:`genindex`
   * :ref:`modindex`
   * :ref:`search`
